pub struct MockAccessPoliciesApi {
AccessPoliciesApi_expectations: MockAccessPoliciesApi_AccessPoliciesApi,
}Fields
AccessPoliciesApi_expectations: MockAccessPoliciesApi_AccessPoliciesApiImplementations
Sourceimpl MockAccessPoliciesApi
impl MockAccessPoliciesApi
Sourcepub fn checkpoint(&mut self)
pub fn checkpoint(&mut self)
Validate that all current expectations for all methods have been satisfied, and discard them.
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new mock object with no expectations.
This method will not be generated if the real struct
already has a new method. However, it will be
generated if the struct implements a trait with a new
method. The trait’s new method can still be called
like <MockX as TraitY>::new
Sourceimpl MockAccessPoliciesApi
impl MockAccessPoliciesApi
Sourcepub fn expect_get_people_potential_grantees(&mut self) -> &mut Expectation
pub fn expect_get_people_potential_grantees(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_people_potential_grantees method
Sourcepub fn expect_get_project_people_access_policies(&mut self) -> &mut Expectation
pub fn expect_get_project_people_access_policies(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_project_people_access_policies method
Sourcepub fn expect_get_project_potential_grantees(&mut self) -> &mut Expectation
pub fn expect_get_project_potential_grantees(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_project_potential_grantees method
Sourcepub fn expect_get_project_service_accounts_access_policies(
&mut self,
) -> &mut Expectation
pub fn expect_get_project_service_accounts_access_policies( &mut self, ) -> &mut Expectation
Create an Expectation for mocking the get_project_service_accounts_access_policies method
Sourcepub fn expect_get_secret_access_policies(&mut self) -> &mut Expectation
pub fn expect_get_secret_access_policies(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_secret_access_policies method
Sourcepub fn expect_get_service_account_granted_policies(
&mut self,
) -> &mut Expectation
pub fn expect_get_service_account_granted_policies( &mut self, ) -> &mut Expectation
Create an Expectation for mocking the get_service_account_granted_policies method
Sourcepub fn expect_get_service_account_people_access_policies(
&mut self,
) -> &mut Expectation
pub fn expect_get_service_account_people_access_policies( &mut self, ) -> &mut Expectation
Create an Expectation for mocking the get_service_account_people_access_policies method
Sourcepub fn expect_get_service_accounts_potential_grantees(
&mut self,
) -> &mut Expectation
pub fn expect_get_service_accounts_potential_grantees( &mut self, ) -> &mut Expectation
Create an Expectation for mocking the get_service_accounts_potential_grantees method
Sourcepub fn expect_put_project_people_access_policies(&mut self) -> &mut Expectation
pub fn expect_put_project_people_access_policies(&mut self) -> &mut Expectation
Create an Expectation for mocking the put_project_people_access_policies method
Sourcepub fn expect_put_project_service_accounts_access_policies(
&mut self,
) -> &mut Expectation
pub fn expect_put_project_service_accounts_access_policies( &mut self, ) -> &mut Expectation
Create an Expectation for mocking the put_project_service_accounts_access_policies method
Sourcepub fn expect_put_service_account_granted_policies(
&mut self,
) -> &mut Expectation
pub fn expect_put_service_account_granted_policies( &mut self, ) -> &mut Expectation
Create an Expectation for mocking the put_service_account_granted_policies method
Sourcepub fn expect_put_service_account_people_access_policies(
&mut self,
) -> &mut Expectation
pub fn expect_put_service_account_people_access_policies( &mut self, ) -> &mut Expectation
Create an Expectation for mocking the put_service_account_people_access_policies method